============
Installation
============

------------
Requirements
------------

**The major requirement of fileslice is python 3. fileslice is a python 3
library and was never tested in python 2. So first make sure your version of
python is 3.**

------------
Installation
------------

Make sure you have pip for python 3 installed.

On windows install using pip by running the
command::
    
    pip install fileslice

Or on linux::
    
    pip3 install fileslice

Of course, pip command should be in your PATH environment variable. If you are
using windows there is a good chance pip is not in your PATH. In this case you
should specify the full pip path. Search about how to use pip on windows if you
are having trouble.

Try to import fileslice to be sure it was installed successfully::

    >>> import fileslice
    >>>

If it is imported without errors, you are ready to use it. You may want to have
a look at one or more of the following documents:
    
* :doc:`quick-guide` For usage examples.
* :doc:`reference` This is the library reference. All classes and functions
    documentation is here.

